Train one model
COPY_biglasso_part(X, y.train, ind.train, ind.col, covar.train, family,
lambda, center, scale, resid, alpha, eps, max.iter, dfmax, ind.val,
covar.val, y.val, n.abort, nlam.min, base.train, base.val, pf)A named list with following variables:
A vector of intercepts, corresponding to each lambda.
The vector of coefficients that minimized the loss on the validation set.
A vector of length nlambda containing the number of
iterations until convergence at each value of lambda.
The sequence of regularization parameter values in the path.
Input parameter.
A vector containing either the residual sum of squares
(for linear models) or negative log-likelihood (for logistic models)
of the fitted model at each value of lambda.
A vector containing the loss for the corresponding validation set.
Reason the fitting has stopped.
The number of active (non-zero) variables along the regularization path.
The number of candidate variables (used in the gradient descent) along the regularization path.
Indices of training set.